@@ -3,14 +3,6 @@ set -euo pipefail
 
 export ARTIFACT_NAME="yazi-$1"
 export YAZI_GEN_COMPLETIONS=1
-export MACOSX_DEPLOYMENT_TARGET="10.11"
-
-# Setup Rust toolchain
-if [[ "$1" == *-musl ]]; then
-	rustup target add "$1"
-else
-	rustup toolchain install stable --profile minimal --target "$1"
-fi
 
 # Build for the target
 cargo build --release --locked --target "$1"
