@@ -81,9 +81,9 @@ impl Adapter {
 
 impl Adapter {
 	pub fn matches(emulator: Emulator) -> Self {
-		if matches!(emulator.kind.left(), Some(Brand::Microsoft)) {
+		if emulator.kind.is_left_and(|&b| b == Brand::Microsoft) {
 			return Self::Sixel;
-		} else if *WSL && matches!(emulator.kind.left(), Some(Brand::WezTerm)) {
+		} else if WSL.get() && emulator.kind.is_left_and(|&b| b == Brand::WezTerm) {
 			return Self::KgpOld;
 		}
 
@@ -92,7 +92,7 @@ impl Adapter {
 		protocols.retain(|p| *p == Self::Iip);
 		if env_exists("ZELLIJ_SESSION_NAME") {
 			protocols.retain(|p| *p == Self::Sixel);
-		} else if *TMUX {
+		} else if TMUX.get() {
 			protocols.retain(|p| *p != Self::KgpOld);
 		}
 		if let Some(p) = protocols.first() {
