@@ -1,9 +1,9 @@
 use tracing::warn;
 use yazi_shared::env_exists;
 
-use crate::{Mux, NVIM};
+use crate::Mux;
 
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum Brand {
 	Kitty,
 	Konsole,
@@ -13,26 +13,37 @@ pub enum Brand {
 	Ghostty,
 	Microsoft,
 	Rio,
-	Alacritty,
 	BlackBox,
 	VSCode,
 	Tabby,
 	Hyper,
 	Mintty,
-	Neovim,
+	Tmux,
+	VTerm,
 	Apple,
 	Urxvt,
 	Bobcat,
 }
 
 impl Brand {
+	pub(super) fn from_csi(resp: &str) -> Option<Self> {
+		let names = [
+			("kitty", Self::Kitty),
+			("Konsole", Self::Konsole),
+			("iTerm2", Self::Iterm2),
+			("WezTerm", Self::WezTerm),
+			("foot", Self::Foot),
+			("ghostty", Self::Ghostty),
+			("tmux ", Self::Tmux),
+			("libvterm", Self::VTerm),
+			("Bobcat", Self::Bobcat),
+		];
+		names.into_iter().find(|&(n, _)| resp.contains(n)).map(|(_, b)| b)
+	}
+
 	pub fn from_env() -> Option<Self> {
 		use Brand as B;
 
-		if *NVIM {
-			return Some(Self::Neovim);
-		}
-
 		let vars = [
 			("KITTY_WINDOW_ID", B::Kitty),
 			("KONSOLE_VERSION", B::Konsole),
@@ -40,7 +51,6 @@ impl Brand {
 			("WEZTERM_EXECUTABLE", B::WezTerm),
 			("GHOSTTY_RESOURCES_DIR", B::Ghostty),
 			("WT_Session", B::Microsoft),
-			("ALACRITTY_WINDOW_ID", B::Alacritty),
 			("VSCODE_INJECTION", B::VSCode),
 			("TABBY_CONFIG_DIRECTORY", B::Tabby),
 		];
@@ -69,26 +79,12 @@ impl Brand {
 			"foot-extra" => return Some(B::Foot),
 			"xterm-ghostty" => return Some(B::Ghostty),
 			"rio" => return Some(B::Rio),
-			"alacritty" => return Some(B::Alacritty),
 			"rxvt-unicode-256color" => return Some(B::Urxvt),
 			_ => warn!("[Adapter] Unknown TERM: {term}"),
 		}
 		None
 	}
 
-	pub(super) fn from_csi(resp: &str) -> Option<Self> {
-		let names = [
-			("kitty", Self::Kitty),
-			("Konsole", Self::Konsole),
-			("iTerm2", Self::Iterm2),
-			("WezTerm", Self::WezTerm),
-			("foot", Self::Foot),
-			("ghostty", Self::Ghostty),
-			("Bobcat", Self::Bobcat),
-		];
-		names.into_iter().find(|&(n, _)| resp.contains(n)).map(|(_, b)| b)
-	}
-
 	pub(super) fn adapters(self) -> &'static [crate::Adapter] {
 		use Brand as B;
 
@@ -103,13 +99,13 @@ impl Brand {
 			B::Ghostty => &[A::Kgp],
 			B::Microsoft => &[A::Sixel],
 			B::Rio => &[A::Iip, A::Sixel],
-			B::Alacritty => &[],
 			B::BlackBox => &[A::Sixel],
 			B::VSCode => &[A::Iip, A::Sixel],
 			B::Tabby => &[A::Iip, A::Sixel],
 			B::Hyper => &[A::Iip, A::Sixel],
 			B::Mintty => &[A::Iip],
-			B::Neovim => &[],
+			B::Tmux => &[],
+			B::VTerm => &[],
 			B::Apple => &[],
 			B::Urxvt => &[],
 			B::Bobcat => &[A::Iip, A::Sixel],
