@@ -1,6 +1,6 @@
 use yazi_fs::Step;
 use yazi_macro::render;
-use yazi_proxy::ManagerProxy;
+use yazi_proxy::MgrProxy;
 use yazi_shared::event::CmdCow;
 
 use crate::tab::Tab;
@@ -24,7 +24,7 @@ impl Tab {
 	pub fn arrow(&mut self, opt: Opt) {
 		// TODO: remove this
 		if let Step::Fixed(n) = opt.step {
-			if n <= -999 || n >= 999 {
+			if n <= -999999 || n >= 999999 {
 				yazi_proxy::AppProxy::notify_warn(
 					"Deprecated command",
 					"`arrow -99999999` and `arrow 99999999` have been deprecated, please use `arrow top` and `arrow bot` instead.
@@ -48,7 +48,7 @@ See #2294 for more details: https://github.com/sxyazi/yazi/pull/2294",
 			}
 		}
 
-		ManagerProxy::hover(None, self.id);
+		MgrProxy::hover(None, self.id);
 		render!();
 	}
 }
