@@ -1,15 +1,15 @@
-use std::{io::{stderr, BufWriter, LineWriter, Write}, mem};
+use std::{io::{BufWriter, LineWriter, Write, stderr}, mem};
 
 use crossterm::terminal::{disable_raw_mode, enable_raw_mode};
 use scopeguard::defer;
-use tokio::{io::{stdin, AsyncReadExt}, select, sync::mpsc, time};
+use tokio::{io::{AsyncReadExt, stdin}, select, sync::mpsc, time};
 use yazi_proxy::{AppProxy, HIDER};
-use yazi_shared::{event::Cmd, terminal_clear};
+use yazi_shared::{event::CmdCow, terminal_clear};
 
 use crate::tasks::Tasks;
 
 impl Tasks {
-	pub fn inspect(&self, _: Cmd) {
+	pub fn inspect(&self, _: CmdCow) {
 		let ongoing = self.ongoing().clone();
 		let Some(id) = ongoing.lock().get_id(self.cursor) else {
 			return;
