@@ -1,12 +1,10 @@
 use yazi_config::keymap::{ChordCow, Key};
 use yazi_macro::{emit, render_and};
-use yazi_shared::Layer;
 
 #[derive(Default)]
 pub struct Which {
-	pub(super) layer: Layer,
-	pub times:        usize,
-	pub cands:        Vec<ChordCow>,
+	pub times: usize,
+	pub cands: Vec<ChordCow>,
 
 	// Visibility
 	pub visible: bool,
@@ -21,10 +19,10 @@ impl Which {
 		if self.cands.is_empty() {
 			self.reset();
 		} else if self.cands.len() == 1 {
-			emit!(Seq(self.cands.remove(0).into_seq(), self.layer));
+			emit!(Seq(self.cands.remove(0).into_seq()));
 			self.reset();
 		} else if let Some(i) = self.cands.iter().position(|c| c.on.len() == self.times) {
-			emit!(Seq(self.cands.remove(i).into_seq(), self.layer));
+			emit!(Seq(self.cands.remove(i).into_seq()));
 			self.reset();
 		}
 
