@@ -12,17 +12,17 @@ impl<'a> Executor<'a> {
 	pub(super) fn new(app: &'a mut App) -> Self { Self { app } }
 
 	#[inline]
-	pub(super) fn execute(&mut self, cmd: CmdCow, layer: Layer) {
-		match layer {
+	pub(super) fn execute(&mut self, cmd: CmdCow) {
+		match cmd.layer {
 			Layer::App => self.app(cmd),
-			Layer::Manager => self.manager(cmd),
+			Layer::Mgr => self.mgr(cmd),
 			Layer::Tasks => self.tasks(cmd),
 			Layer::Spot => self.spot(cmd),
 			Layer::Pick => self.pick(cmd),
 			Layer::Input => self.input(cmd),
 			Layer::Confirm => self.confirm(cmd),
 			Layer::Help => self.help(cmd),
-			Layer::Completion => self.completion(cmd),
+			Layer::Cmp => self.cmp(cmd),
 			Layer::Which => self.which(cmd),
 		}
 	}
@@ -47,44 +47,44 @@ impl<'a> Executor<'a> {
 		on!(resume);
 	}
 
-	fn manager(&mut self, cmd: CmdCow) {
+	fn mgr(&mut self, cmd: CmdCow) {
 		macro_rules! on {
-			(MANAGER, $name:ident $(,$args:expr)*) => {
+			(MGR, $name:ident $(,$args:expr)*) => {
 				if cmd.name == stringify!($name) {
-					return self.app.cx.manager.$name(cmd, $($args),*);
+					return self.app.cx.mgr.$name(cmd, $($args),*);
 				}
 			};
 			(ACTIVE, $name:ident $(,$args:expr)*) => {
 				if cmd.name == stringify!($name) {
 					return if let Some(tab) = cmd.get("tab") {
 						let Some(id) = tab.as_id() else { return };
-						let Some(tab) = self.app.cx.manager.tabs.find_mut(id) else { return };
+						let Some(tab) = self.app.cx.mgr.tabs.find_mut(id) else { return };
 						tab.$name(cmd, $($args),*)
 					} else {
-						self.app.cx.manager.active_mut().$name(cmd, $($args),*)
+						self.app.cx.mgr.active_mut().$name(cmd, $($args),*)
 					};
 				}
 			};
 			(TABS, $name:ident) => {
 				if cmd.name == concat!("tab_", stringify!($name)) {
-					return self.app.cx.manager.tabs.$name(cmd);
+					return self.app.cx.mgr.tabs.$name(cmd);
 				}
 			};
 		}
 
-		on!(MANAGER, update_tasks);
-		on!(MANAGER, update_files, &self.app.cx.tasks);
-		on!(MANAGER, update_mimes, &self.app.cx.tasks);
-		on!(MANAGER, update_paged, &self.app.cx.tasks);
-		on!(MANAGER, update_yanked);
-		on!(MANAGER, hover);
-		on!(MANAGER, peek);
-		on!(MANAGER, seek);
-		on!(MANAGER, spot);
-		on!(MANAGER, refresh, &self.app.cx.tasks);
-		on!(MANAGER, quit, &self.app.cx.tasks);
-		on!(MANAGER, close, &self.app.cx.tasks);
-		on!(MANAGER, suspend);
+		on!(MGR, update_tasks);
+		on!(MGR, update_files, &self.app.cx.tasks);
+		on!(MGR, update_mimes, &self.app.cx.tasks);
+		on!(MGR, update_paged, &self.app.cx.tasks);
+		on!(MGR, update_yanked);
+		on!(MGR, hover);
+		on!(MGR, peek);
+		on!(MGR, seek);
+		on!(MGR, spot);
+		on!(MGR, refresh, &self.app.cx.tasks);
+		on!(MGR, quit, &self.app.cx.tasks);
+		on!(MGR, close, &self.app.cx.tasks);
+		on!(MGR, suspend);
 		on!(ACTIVE, escape);
 		on!(ACTIVE, update_peeked);
 		on!(ACTIVE, update_spotted);
@@ -104,17 +104,17 @@ impl<'a> Executor<'a> {
 		on!(ACTIVE, visual_mode);
 
 		// Operation
-		on!(MANAGER, open, &self.app.cx.tasks);
-		on!(MANAGER, open_do, &self.app.cx.tasks);
-		on!(MANAGER, yank);
-		on!(MANAGER, unyank);
-		on!(MANAGER, paste, &self.app.cx.tasks);
-		on!(MANAGER, link, &self.app.cx.tasks);
-		on!(MANAGER, hardlink, &self.app.cx.tasks);
-		on!(MANAGER, remove, &self.app.cx.tasks);
-		on!(MANAGER, remove_do, &self.app.cx.tasks);
-		on!(MANAGER, create);
-		on!(MANAGER, rename);
+		on!(MGR, open, &self.app.cx.tasks);
+		on!(MGR, open_do, &self.app.cx.tasks);
+		on!(MGR, yank);
+		on!(MGR, unyank);
+		on!(MGR, paste, &self.app.cx.tasks);
+		on!(MGR, link, &self.app.cx.tasks);
+		on!(MGR, hardlink, &self.app.cx.tasks);
+		on!(MGR, remove, &self.app.cx.tasks);
+		on!(MGR, remove_do, &self.app.cx.tasks);
+		on!(MGR, create);
+		on!(MGR, rename);
 		on!(ACTIVE, copy);
 		on!(ACTIVE, shell);
 		on!(ACTIVE, hidden);
@@ -144,7 +144,7 @@ impl<'a> Executor<'a> {
 			// Tasks
 			"tasks_show" => self.app.cx.tasks.toggle(()),
 			// Help
-			"help" => self.app.cx.help.toggle(Layer::Manager),
+			"help" => self.app.cx.help.toggle(Layer::Mgr),
 			// Plugin
 			"plugin" => self.app.plugin(cmd),
 			_ => {}
@@ -249,7 +249,7 @@ impl<'a> Executor<'a> {
 
 		if cmd.name.as_str() == "complete" {
 			return if cmd.bool("trigger") {
-				self.app.cx.completion.trigger(cmd)
+				self.app.cx.cmp.trigger(cmd)
 			} else {
 				self.app.cx.input.complete(cmd)
 			};
@@ -293,7 +293,7 @@ impl<'a> Executor<'a> {
 			};
 		}
 
-		on!(arrow, &self.app.cx.manager);
+		on!(arrow, &self.app.cx.mgr);
 		on!(show);
 		on!(close);
 	}
@@ -319,11 +319,11 @@ impl<'a> Executor<'a> {
 		}
 	}
 
-	fn completion(&mut self, cmd: CmdCow) {
+	fn cmp(&mut self, cmd: CmdCow) {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
-					return self.app.cx.completion.$name(cmd);
+					return self.app.cx.cmp.$name(cmd);
 				}
 			};
 		}
@@ -336,7 +336,7 @@ impl<'a> Executor<'a> {
 		match cmd.name.as_str() {
 			"close_input" => self.app.cx.input.close(cmd),
 			// Help
-			"help" => self.app.cx.help.toggle(Layer::Completion),
+			"help" => self.app.cx.help.toggle(Layer::Cmp),
 			// Plugin
 			"plugin" => self.app.plugin(cmd),
 			_ => {}
