@@ -5,7 +5,7 @@ use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnh
 use cursor::RestoreCursor;
 use ratatui::{CompletedFrame, Frame, Terminal, backend::CrosstermBackend, buffer::Buffer, layout::Rect};
 use yazi_adapter::{Emulator, Mux};
-use yazi_config::{INPUT, MANAGER};
+use yazi_config::{INPUT, MGR};
 
 static CSI_U: AtomicBool = AtomicBool::new(false);
 static BLINK: AtomicBool = AtomicBool::new(false);
@@ -26,7 +26,7 @@ impl Term {
 		};
 
 		enable_raw_mode()?;
-		if *yazi_adapter::TMUX {
+		if yazi_adapter::TMUX.get() {
 			yazi_adapter::Mux::tmux_passthrough();
 		}
 
@@ -42,13 +42,14 @@ impl Term {
 			mouse::SetMouse(true),
 		)?;
 
-		let da = futures::executor::block_on(Emulator::read_until_da1());
+		let resp = Emulator::read_until_da1();
 		Mux::tmux_drain()?;
 
-		CSI_U.store(da.contains("\x1b[?0u"), Ordering::Relaxed);
-		BLINK.store(da.contains("\x1b[?12;1$y"), Ordering::Relaxed);
+		CSI_U.store(resp.contains("\x1b[?0u"), Ordering::Relaxed);
+		BLINK.store(resp.contains("\x1b[?12;1$y"), Ordering::Relaxed);
 		SHAPE.store(
-			da.split_once("\x1bP1$r")
+			resp
+				.split_once("\x1bP1$r")
 				.and_then(|(_, s)| s.bytes().next())
 				.filter(|&b| matches!(b, b'0'..=b'6'))
 				.map_or(u8::MAX, |b| b - b'0'),
@@ -93,7 +94,7 @@ impl Term {
 			execute!(stderr(), PopKeyboardEnhancementFlags).ok();
 		}
 
-		if !MANAGER.title_format.is_empty() {
+		if !MGR.title_format.is_empty() {
 			execute!(stderr(), SetTitle("")).ok();
 		}
 
@@ -189,13 +190,13 @@ impl DerefMut for Term {
 // --- Mouse support
 mod mouse {
 	use crossterm::event::{DisableMouseCapture, EnableMouseCapture};
-	use yazi_config::MANAGER;
+	use yazi_config::MGR;
 
 	pub struct SetMouse(pub bool);
 
 	impl crossterm::Command for SetMouse {
 		fn write_ansi(&self, f: &mut impl std::fmt::Write) -> std::fmt::Result {
-			if MANAGER.mouse_events.is_empty() {
+			if MGR.mouse_events.is_empty() {
 				Ok(())
 			} else if self.0 {
 				EnableMouseCapture.write_ansi(f)
@@ -206,7 +207,7 @@ mod mouse {
 
 		#[cfg(windows)]
 		fn execute_winapi(&self) -> std::io::Result<()> {
-			if MANAGER.mouse_events.is_empty() {
+			if MGR.mouse_events.is_empty() {
 				Ok(())
 			} else if self.0 {
 				EnableMouseCapture.execute_winapi()
@@ -268,12 +269,12 @@ mod screen {
 
 	impl crossterm::Command for SetScreen {
 		fn write_ansi(&self, f: &mut impl std::fmt::Write) -> std::fmt::Result {
-			if self.0 == *TMUX { Ok(()) } else { EnterAlternateScreen.write_ansi(f) }
+			if self.0 == TMUX.get() { Ok(()) } else { EnterAlternateScreen.write_ansi(f) }
 		}
 
 		#[cfg(windows)]
 		fn execute_winapi(&self) -> std::io::Result<()> {
-			if self.0 == *TMUX { Ok(()) } else { EnterAlternateScreen.execute_winapi() }
+			if self.0 == TMUX.get() { Ok(()) } else { EnterAlternateScreen.execute_winapi() }
 		}
 
 		#[cfg(windows)]
