@@ -29,10 +29,12 @@ function M:peek(job)
 
 	child:start_kill()
 	if job.skip > 0 and i < job.skip + limit then
-		ya.manager_emit("peek", { math.max(0, i - limit), only_if = job.file.url, upper_bound = true })
+		ya.mgr_emit("peek", { math.max(0, i - limit), only_if = job.file.url, upper_bound = true })
 	else
-		lines = lines:gsub("\t", string.rep(" ", PREVIEW.tab_size))
-		ya.preview_widgets(job, { ui.Text.parse(lines):area(job.area) })
+		lines = lines:gsub("\t", string.rep(" ", rt.preview.tab_size))
+		ya.preview_widgets(job, {
+			ui.Text.parse(lines):area(job.area):wrap(rt.preview.wrap == "yes" and ui.Text.WRAP or ui.Text.WRAP_NO),
+		})
 	end
 end
 
