@@ -1,10 +1,10 @@
-use mlua::{AnyUserData, Lua, Table, UserDataRef};
+use mlua::{AnyUserData, IntoLua, Lua, Table, UserDataRef};
 
-use crate::{bindings::{Cast, Cha}, impl_file_fields, impl_file_methods};
+use crate::{bindings::Cha, impl_file_fields, impl_file_methods};
 
 pub type FileRef = UserDataRef<yazi_fs::File>;
 
-pub struct File;
+pub struct File(pub yazi_fs::File);
 
 impl File {
 	#[inline]
@@ -18,17 +18,19 @@ impl File {
 	pub fn install(lua: &Lua) -> mlua::Result<()> {
 		lua.globals().raw_set(
 			"File",
-			lua.create_function(|lua, t: Table| {
-				Self::cast(lua, yazi_fs::File {
+			lua.create_function(|_, t: Table| {
+				Ok(Self(yazi_fs::File {
 					url: t.raw_get::<AnyUserData>("url")?.take()?,
 					cha: *t.raw_get::<Cha>("cha")?,
 					..Default::default()
-				})
+				}))
 			})?,
 		)
 	}
 }
 
-impl<T: Into<yazi_fs::File>> Cast<T> for File {
-	fn cast(lua: &Lua, data: T) -> mlua::Result<AnyUserData> { lua.create_any_userdata(data.into()) }
+impl IntoLua for File {
+	fn into_lua(self, lua: &Lua) -> mlua::Result<mlua::Value> {
+		lua.create_any_userdata(self.0)?.into_lua(lua)
+	}
 }
