@@ -9,7 +9,7 @@ impl Status {
 }
 
 impl UserData for Status {
-	fn add_fields<'lua, F: mlua::UserDataFields<'lua, Self>>(fields: &mut F) {
+	fn add_fields<F: mlua::UserDataFields<Self>>(fields: &mut F) {
 		fields.add_field_method_get("success", |_, me| Ok(me.inner.success()));
 		fields.add_field_method_get("code", |_, me| Ok(me.inner.code()));
 	}
