@@ -1,7 +1,7 @@
 use mlua::{Function, IntoLuaMulti, Lua, LuaSerdeExt, Value};
 
 use super::Utils;
-use crate::{Error, config::SER_OPTS};
+use crate::{Error, config::OPTS};
 
 impl Utils {
 	pub(super) fn json_encode(lua: &Lua) -> mlua::Result<Function> {
@@ -16,7 +16,7 @@ impl Utils {
 	pub(super) fn json_decode(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_async_function(|lua, s: mlua::String| async move {
 			match serde_json::from_slice::<serde_json::Value>(&s.as_bytes()) {
-				Ok(v) => (lua.to_value_with(&v, SER_OPTS)?, Value::Nil).into_lua_multi(&lua),
+				Ok(v) => (lua.to_value_with(&v, OPTS)?, Value::Nil).into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Serde(e)).into_lua_multi(&lua),
 			}
 		})
