@@ -1,5 +1,5 @@
 use yazi_macro::emit;
-use yazi_shared::{Layer, event::Cmd, url::Url};
+use yazi_shared::{event::Cmd, url::Url};
 
 use crate::options::SearchOpt;
 
@@ -8,25 +8,24 @@ pub struct TabProxy;
 impl TabProxy {
 	#[inline]
 	pub fn cd(target: &Url) {
-		emit!(Call(Cmd::args("cd", &[target]), Layer::Manager));
+		emit!(Call(Cmd::args("mgr:cd", &[target])));
 	}
 
 	#[inline]
 	pub fn reveal(target: &Url) {
-		emit!(Call(Cmd::args("reveal", &[target]), Layer::Manager));
+		emit!(Call(Cmd::args("mgr:reveal", &[target])));
 	}
 
 	#[inline]
 	pub fn arrow(step: isize) {
-		emit!(Call(Cmd::args("arrow", &[step]), Layer::Manager));
+		emit!(Call(Cmd::args("mgr:arrow", &[step])));
 	}
 
 	#[inline]
 	pub fn search_do(opt: SearchOpt) {
 		emit!(Call(
 			// TODO: use second positional argument instead of `args` parameter
-			Cmd::args("search_do", &[opt.subject]).with("via", opt.via).with("args", opt.args_raw),
-			Layer::Manager
+			Cmd::args("mgr:search_do", &[opt.subject]).with("via", opt.via).with("args", opt.args_raw)
 		));
 	}
 }
